from setuptools import setup

setup(name='estimotty',
      version='0.1.1',
      description='Estimote cloud client',
      url='https://github.com/OpenInfoporto/python-estimotty.git',
      author='Andrea Carmisciano',
      author_email='andrea.carmisciano@infoporto.it',
      license='MIT',
      packages=['estimotty'],
      zip_safe=False)
